﻿using Hotline.FlowEngine.Definitions;
using Hotline.FlowEngine.Workflows;
using Hotline.Share.Dtos.FlowEngine;
using Hotline.Share.Enums.FlowEngine;
using XF.Domain.Dependency;
using XF.Domain.Exceptions;

namespace Hotline.Application.FlowEngine;

public class WorkflowApplication : IWorkflowApplication, IScopeDependency
{
    private readonly IDefinitionDomainService _definitionDomainService;
    private readonly IWorkflowDomainService _workflowDomainService;
    private readonly IWorkflowRepository _workflowRepository;

    public WorkflowApplication(
        IDefinitionDomainService definitionDomainService,
        IWorkflowDomainService workflowDomainService,
        IWorkflowRepository workflowRepository)
    {
        _definitionDomainService = definitionDomainService;
        _workflowDomainService = workflowDomainService;
        _workflowRepository = workflowRepository;
    }

    public async Task<string> StartWorkflowAsync(StartWorkflowDto dto, CancellationToken cancellationToken = default)
    {
        var definition = await _definitionDomainService.GetLastVersionDefinitionAsync(dto.DefinitionCode, cancellationToken);
        if (definition == null)
            throw new UserFriendlyException("无效模板名称");
        if (definition.Status != EDefinitionStatus.Enable)
            throw new UserFriendlyException("该模板不可用");
        var workflow = _workflowDomainService.CreateWorkflow(definition, dto);
        _workflowDomainService.AddStartTrace(workflow, dto);

        //todo 交给 back process 处理
        //await _workflowDomainService.RunNormalStepAsync(workflow, cancellationToken);

        var workflowId = await _workflowRepository.AddAsync(workflow, cancellationToken);
        //todo publish notify

        return workflowId;
    }

    //public async Task<string> StartWorkflowAsync<TData>(string definitionName, TData? data, CancellationToken cancellationToken = default) where TData : class, new()
    //{
    //    throw new NotImplementedException();
    //}
}