﻿using Hotline.Repository.SqlSugar.DataPermissions;
using Hotline.Settings;
using SqlSugar;
using XF.Domain.Dependency;

namespace Hotline.Repository.SqlSugar.System
{
    public class SystemOrganizeRepository : BaseRepository<SystemOrganize>, ISystemOrganizeRepository, IScopeDependency
    {
        public SystemOrganizeRepository(ISugarUnitOfWork<HotlineDbContext> uow, IDataPermissionFilterBuilder dataPermissionFilterBuilder) : base(uow, dataPermissionFilterBuilder)
        {
        }


        public async Task<IReadOnlyList<SystemOrganize>> GetOrgJson()
        {
            var list = await Db.Queryable<SystemOrganize>()
                .ToTreeAsync(x => x.children, it => it.ParentId, "");
            return list;
        }

        public async Task<IReadOnlyList<SystemOrganize>> GetCanUseOrg()
        {
            var list = await Db.Queryable<SystemOrganize>()
                .Where(x => x.IsEnable)
                .ToTreeAsync(x => x.children, it => it.ParentId, "");
            return list;
        }

        public async Task<string> GetNewOrgCode(string? parentId)
        {
            //有父级
            if (!string.IsNullOrEmpty(parentId))
            {
                //查是否存在下级
                var model = await Db.Queryable<SystemOrganize>()
                    .OrderByDescending(x => x.OrgCode)
                    .FirstAsync(x => x.ParentId == parentId);
                //如果存在下级
                if (model!=null)
                {
                    //return $"{int.Parse(model.OrgCode) +1:###}";
                    return (int.Parse(model.OrgCode) + 1).ToString().PadLeft(3,'0');
                }
                //如果不存在下级
                else
                {
                    var parentModel = await Db.Queryable<SystemOrganize>()
                        .FirstAsync(x => x.Id == parentId);
                    return parentModel.OrgCode + "001";
                }
            }
            //没有父级
            else
            {
                //查询最大数值
                var model = await Db.Queryable<SystemOrganize>()
                    .OrderByDescending(x => x.OrgCode)
                    .FirstAsync(x => x.ParentId=="");
                if (model!=null)
                {
                    //return $"{int.Parse(model.OrgCode) + 1:###}";
                    return (int.Parse(model.OrgCode) + 1).ToString().PadLeft(3,'0');
                }
                return "001";
            }
        }
    }
}
