﻿using Hotline.CallCenter.Calls;
using XF.Domain.Cache;
using XF.Domain.Dependency;

namespace Hotline.Caches
{
    public class CallCacheManager:ICallCacheManager, IScopeDependency
    {
        private readonly ITypedCache<IReadOnlyList<Call>> _cacheCall;
        private const string CallKey = "CallQueue";

        public CallCacheManager(ITypedCache<IReadOnlyList<Call>> cacheCall)
        {
            _cacheCall = cacheCall;
        }

        /// <summary>
        /// 获取队列
        /// </summary>
        /// <returns></returns>
        public IReadOnlyList<Call> GetCallQueueList()
        {
            return _cacheCall.Get(CallKey)??new List<Call>();
        }

        /// <summary>
        /// 新增或修改队列
        /// </summary>
        /// <param name="list"></param>
        public void AddOrUpdateCallCache(List<Call> list)
        {
            _cacheCall.AddOrUpdate(CallKey, list);
        }

        /// <summary>
        /// 删除队列
        /// </summary>
        /// <param name="id"></param>
        /// <exception cref="NotImplementedException"></exception>
        public void RemoveCallCache(string id)
        {
            var list = _cacheCall.Get(CallKey)?.ToList();
            if (list!=null)
            {
                var model = list.First(x=>x.Id == id);
                if (model!=null)
                {
                    list.Remove(model);
                    _cacheCall.AddOrUpdate(CallKey,list);
                }
            }
        }
    }
}
