﻿using Hotline.FlowEngine.Definitions;
using Hotline.Share.Enums.FlowEngine;
using SqlSugar;
using XF.Domain.Repository;

namespace Hotline.FlowEngine.Workflows;

//public class StepBox : StepBasic
//{
//    public DateTime? StartTime { get; set; } = DateTime.Now;

//    public DateTime? EndTime { get; set; }

//    public List<Step> Steps { get; set; } = new();
//}

public class WorkflowStep : StepBasicEntity
{
    public string WorkflowId { get; set; }

    [SugarColumn(IsNullable = true)]
    public string? ParentId { get; set; }

    [SugarColumn(ColumnDataType = "varchar(4000)", IsJson = true)]
    public List<NextStep> NextSteps { get; set; }
    
    /// <summary>
    /// 被指派处理对象（依据不同指派方式可能为：depCode或userId）
    /// </summary>
    public string HandlerId { get; set; }

    public DateTime? StartTime { get; set; } = DateTime.Now;

    public DateTime? EndTime { get; set; }

    public string PreviousId { get; set; }

    #region 审批参数

    /// <summary>
    /// (下一节点处理人)根据审批者类型不同，此字段为不同内容
    /// <example>
    /// 部门等级/分类为：depCodes, 角色为：userIds
    /// </example>
    /// </summary>
    [SugarColumn(ColumnDataType = "varchar(4000)", IsJson = true)]
    public List<string> Handlers { get; set; }

    /// <summary>
    /// 下一节点code
    /// </summary>
    public string NextStepCode { get; set; }

    /// <summary>
    /// 是否短信通知
    /// </summary>
    public bool AcceptSms { get; set; }

    /// <summary>
    /// 办理意见
    /// </summary>
    public string Opinion { get; set; }

    #endregion

    [SugarColumn(IsIgnore = true)]
    public List<WorkflowStep> Steps { get; set; }
}

public class StepBasicEntity : CreationEntity
{
    public string Name { get; set; }

    /// <summary>
    /// 模板内唯一
    /// </summary>
    public string Code { get; set; }

    public string TypeName { get; init; }

    public EStepType StepType { get; init; }

    /// <summary>
    /// 审批者类型
    /// </summary>
    public EHandlerType HandlerType { get; set; }

    /// <summary>
    /// 审批者分类（或是直接保存处理者）
    /// <example>
    /// 根据类型可能为：roles, depLevels, depTypes, depCodes, userIds
    /// </example>
    /// </summary>
    [SugarColumn(ColumnDataType = "varchar(4000)", IsJson = true)]
    public List<string> HandlerClassifies { get; set; } = new();

    /// <summary>
    /// 会签模式
    /// </summary>
    public ECountersignMode CountersignMode { get; set; }

}