﻿using Hotline.Share.Enums.Order;
using SqlSugar;
using XF.Domain.Repository;

namespace Hotline.Orders
{
    /// <summary>
    /// 工单
    /// </summary>
    public partial class Order : FullStateEntity
    {
        #region 来电信息

        /// <summary>
        /// 来源渠道
        /// </summary>
        public EChannel Channel { get; set; }

        /// <summary>
        /// 来电/信人姓名
        /// </summary>
        public string FromName { get; set; }

        /// <summary>
        /// 来电/信人性别
        /// </summary>
        public EGender FromGender { get; set; }

        /// <summary>
        /// 来电/信人身份
        /// </summary>
        public EFromStatus FromStatus { get; set; }

        /// <summary>
        /// 证件类型
        /// </summary>
        public ELicenceType? Licence { get; set; }

        /// <summary>
        /// 证件号码
        /// </summary>
        public string? LicenceNo { get; set; }

        /// <summary>
        /// 年龄段
        /// </summary>
        public EAgeRange? AgeRange { get; set; }

        /// <summary>
        /// 联系电话，null表示无需联系
        /// </summary>
        public string? Contact { get; set; }

        /// <summary>
        /// 是否接受短信，勾选校验手机号
        /// </summary>
        public bool AcceptSms { get; set; }

        /// <summary>
        /// 工作单位(当“来电/信人身份”为“企业”时必填，其他情况非必填)
        /// </summary>
        public string? Company { get; set; }

        #endregion

        #region 诉求信息

        /// <summary>
        /// 工单编码（202201010001）
        /// </summary>
        public string No { get; set; }

        /// <summary>
        /// 工单类型
        /// </summary>
        public EOrderType OrderType { get; set; }

        /// <summary>
        /// 受理类型
        /// </summary>
        public EAcceptType AcceptType { get; set; }

        /// <summary>
        /// 紧急程度
        /// </summary>
        public EEmergencyLevel EmergencyLevel { get; set; } = EEmergencyLevel.Normal;

        public string Title { get; set; }

        public string HotspotId { get; set; }
        public string Hotspot { get; set; }
        public string HotspotSpliceName { get; set; }

        /// <summary>
        /// 事发时间
        /// </summary>
        public DateTime? IncidentTime { get; set; }

        ///// <summary>
        ///// 事发地址
        ///// </summary>
        //[SugarColumn(ColumnDataType = "varchar(4000)", IsJson = true)]
        //public Position IncidentPosition { get; set; } = new();

        ///// <summary>
        ///// 附件
        ///// </summary>
        //[SugarColumn(ColumnDataType = "varchar(4000)", IsJson = true)]
        //public List<string> Additions { get; set; } = new();

        #endregion
    }

    public class Position
    {
        /// <summary>
        /// 经度
        /// </summary>
        public double Longitude { get; set; }

        /// <summary>
        /// 维度
        /// </summary>
        public double Latitude { get; set; }

        /// <summary>
        /// 行政区划编码
        /// </summary>
        public string AreaCode { get; set; }
        public string Province { get; set; }
        public string City { get; set; }
        public string County { get; set; }
        public string Street { get; set; }

        [SugarColumn(IsIgnore = true)]
        public string Address => $"{Province}{City}{County}{Street}";
    }

    /// <summary>
    /// 渠道为电话时存在字段
    /// </summary>
    public partial class Order
    {
        /// <summary>
        /// 来电号码
        /// </summary>
        public string? FromPhone { get; set; }

        /// <summary>
        /// 转接号码（转接来源）
        /// </summary>
        public string? TransferPhone { get; set; }


    }
}
