﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Linq.Expressions;
using System.Text;
using System.Threading.Tasks;
using SqlSugar;
using XF.Domain.Entities;

namespace XF.Domain.Repository
{
    public interface IRepositorySqlSugar<TEntity, TKey> : IRepositoryWithTKey<TEntity, string>
        where TEntity : class, IEntity<string>, new()
    {
        ISugarQueryable<TEntity> Queryable(bool permissionVerify = false);

        Task<(int Total, List<TEntity> Items)> QueryPagedAsync(
            Expression<Func<TEntity, bool>> predicate,
            Func<ISugarQueryable<TEntity>, ISugarQueryable<TEntity>> orderByCreator,
            int pageIndex,
            int pageSize,
            bool permissionVerify = false,
            params (bool isWhere, Expression<Func<TEntity, bool>> expression)[] whereIfs);

        Task<(int Total, List<TEntity> Items)> QueryPagedAsync(Expression<Func<TEntity, bool>> predicate,
            int pageIndex,
            int pageSize,
            Func<ISugarQueryable<TEntity>, ISugarQueryable<TEntity>>? includes = null,
            Func<ISugarQueryable<TEntity>, ISugarQueryable<TEntity>>? orderByCreator = null,
            bool permissionVerify = false,
            params (bool isWhere, Expression<Func<TEntity, bool>> expression)[] whereIfs);

        Task<List<TEntity>> QueryExtAsync(
            Expression<Func<TEntity, bool>> predicate,
            Func<ISugarQueryable<TEntity>, ISugarQueryable<TEntity>>? includes = null,
            Func<ISugarQueryable<TEntity>, ISugarQueryable<TEntity>>? orderByCreator = null,
            bool permissionVerify = false,
            params (bool isWhere, Expression<Func<TEntity, bool>> expression)[] whereIfs);

        Task<List<TEntity>> QueryExtAsync(
            Expression<Func<TEntity, bool>> predicate,
            Func<ISugarQueryable<TEntity>, ISugarQueryable<TEntity>> includes,
            bool permissionVerify = false);

        Task<TEntity> GetExtAsync(
            Expression<Func<TEntity, bool>> predicate,
            Func<ISugarQueryable<TEntity>, ISugarQueryable<TEntity>> includes,
            bool permissionVerify = false);

        Task<TEntity> GetExtAsync(
            TKey id,
            Func<ISugarQueryable<TEntity>, ISugarQueryable<TEntity>> includes,
            bool permissionVerify = false);

        Task UpdateAsync(TEntity entity, bool ignoreNullColumns = true, CancellationToken cancellationToken = default);
    }
}
